// Code generated by go tool dist; DO NOT EDIT.

package cfg

const DefaultPkgConfig = `pkg-config`
func DefaultCC(goos, goarch string) string {
	switch goos+`/`+goarch {
	}
	return "/tmp/build/80754af9/go_1537369810172/_build_env/bin/x86_64-conda_cos6-linux-gnu-cc"
}
func DefaultCXX(goos, goarch string) string {
	switch goos+`/`+goarch {
	}
	return "/tmp/build/80754af9/go_1537369810172/_build_env/bin/x86_64-conda_cos6-linux-gnu-c++"
}
